##############################################################################
#    Copyright (C) 2002  MMmanager.org
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##############################################################################

import os, zLOG, random, sys, re
from Globals import InitializeClass, package_home
from Persistence import Persistent
from AccessControl import ClassSecurityInfo
from Acquisition import aq_base, aq_parent, aq_inner
from OFS.SimpleItem import SimpleItem
from Products.PageTemplates import PageTemplateFile
from Products.CMFCore.utils import UniqueObject, getToolByName
from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.ActionProviderBase import ActionProviderBase
from Products.CMFCore.ActionInformation import ActionInformation, oai
from Products.CMFCore.Expression import Expression, createExprContext

_zptdir = os.path.join(package_home(globals()), 'www')

class ConfigTool( UniqueObject, SimpleItem, ActionProviderBase ):
    """
    A tool for collecting global configuration in a simple layout
    """

    id = 'portal_configuration'
    meta_type = 'Configuration Tool'

    _actions = [ 
                  ActionInformation(
                    id='portal_configuration'
                  , title='Portal Tools'
                  , action=Expression(
                        text='string: ${portal_url}/globalconfig_view')
                  , condition=None
                  , permissions=(CMFCorePermissions.ManagePortal,)
                  , category='global'
                  , visible=1
                  )
                , 
               ]

    security = ClassSecurityInfo()

    manage_options = ( { 'label' : 'Overview', 'action' : 'manage_overview' }
                     ,) + ActionProviderBase.manage_options + SimpleItem.manage_options

    #
    #   ZMI methods
    #
    security.declareProtected( CMFCorePermissions.ManagePortal
                             , 'manage_overview' )
    manage_overview = PageTemplateFile.PageTemplateFile( 'explainConfigTool', _zptdir)

    #
    #   'portal_menutool' interface methods
    #

    security.declarePrivate('listActions')
    def listActions(self, info=None):
        """
        Return actions provided by tool
        """
        return self._actions

    security.declarePublic('getId')
    def getId(self):
        """
        Return the id
        """
        return self.id

    def _listActions(self,append,object,info,ec):
        a = object.listActions(info)
        if a and type(a[0]) is not type({}):
            for ai in a:
                if ai.testCondition(ec):
                    action = ai.getAction(ec)
                    if action['category'] == "configuration":
                        append(action)
        else:
            for i in a:
                if i['category'] == "configuration":
                    append(i)

    security.declareProtected(CMFCorePermissions.ManagePortal, 'listActionsForTool')
    def listActionsForTool(self, toolname):
        """ set a flag on whether we should merge parent layouts """
        portal = getToolByName(self, 'portal_url').getPortalObject()
        ec = createExprContext(portal, portal, None)
        actions = []
        append = actions.append
        if toolname != self.getId():
            tool = getToolByName(self, toolname)
            if hasattr(tool, 'listActions'):
                info = oai(self, portal, None)
                self._listActions(append,tool,info,ec)
                #actions = tool.listActions(info=info)
        return actions


InitializeClass( ConfigTool )
